#!/bin/sh

set -e

if [ -f fw.md5 ]; then
	echo "Verifying md5 checksums"
	md5sum -s -c fw.md5 > /dev/null 2>&1
fi

CUR_IMAGE_FLAG=$(fw_printenv -n image_flag)
SPL_DEV=/dev/mtd0

if [ "$CUR_IMAGE_FLAG" = "a" ]
then
	IMAGE_FLAG="b"
	UBOOT_DEV=/dev/mtd2
	UIMAGE_DEV=/dev/mtd5
	ROOTFS_DEV=/dev/mtd7
else
	IMAGE_FLAG="a"
	UBOOT_DEV=/dev/mtd1
	UIMAGE_DEV=/dev/mtd4
	ROOTFS_DEV=/dev/mtd6
fi

if [ -f spl.bin ]; then
	echo "Updating spl.bin ($SPL_DEV)"
	flash_erase $SPL_DEV 0x0 0x0 > /dev/null 2>&1
	nandwrite -p -s 0x0 $SPL_DEV spl.bin > /dev/null 2>&1
fi

if [ -f u-boot.bin ]; then
	echo "Updating u-boot.bin ($UBOOT_DEV)"
	flash_erase $UBOOT_DEV 0x0 0x0 > /dev/null 2>&1
	nandwrite -p -s 0x0 $UBOOT_DEV u-boot.bin > /dev/null 2>&1

	# Update u-boot in NOR
	fw_setenv update_flag 1
fi

if [ -f uImage ]; then
	echo "Updating uImage ($UIMAGE_DEV)"
	flash_erase $UIMAGE_DEV 0x0 0x0 > /dev/null 2>&1
	nandwrite -p -s 0x0 $UIMAGE_DEV uImage > /dev/null 2>&1
fi

if [ -f rootfs.ubi ]; then
	echo "Updating rootfs.ubi ($ROOTFS_DEV)"
	# WARN: ubiformat may return a non-zero value on success
	set +e
	ubiformat $ROOTFS_DEV -f rootfs.ubi -y > /dev/null 2>&1
	set -e
fi

fw_setenv image_flag $IMAGE_FLAG
echo "Done"

sync